@@ -3,12 +3,14 @@ from django.core.mail import send_mail
 from django.db import models
 from django.template import Context, Template
 from django.template.loader import get_template
+from django.utils.translation import gettext
 
 from django_otp.models import (
     CooldownMixin,
     GenerateNotAllowed,
     SideChannelDevice,
     ThrottlingMixin,
+    TimestampMixin,
 )
 from django_otp.util import hex_validator, random_hex
 
@@ -25,7 +27,7 @@ def key_validator(value):  # pragma: no cover
     return hex_validator()(value)
 
 
-class EmailDevice(CooldownMixin, ThrottlingMixin, SideChannelDevice):
+class EmailDevice(TimestampMixin, CooldownMixin, ThrottlingMixin, SideChannelDevice):
     """
     A :class:`~django_otp.models.SideChannelDevice` that delivers a token to
     the email address saved in this object or alternatively to the user's
@@ -98,18 +100,27 @@ class EmailDevice(CooldownMixin, ThrottlingMixin, SideChannelDevice):
         else:
             body_html = None
 
+        self.send_mail(body, html_message=body_html)
+
+        message = gettext("sent by email")
+
+        return message
+
+    def send_mail(self, body, **kwargs):
+        """
+        A simple wrapper for :func:`django.core.mail.send_mail`.
+
+        Subclasses (e.g. proxy models) may override this to customize delivery.
+
+        """
         send_mail(
             str(settings.OTP_EMAIL_SUBJECT),
             body,
             settings.OTP_EMAIL_SENDER,
             [self.email or self.user.email],
-            html_message=body_html,
+            **kwargs,
         )
 
-        message = "sent by email"
-
-        return message
-
     def verify_token(self, token):
         """"""
         verify_allowed, _ = self.verify_is_allowed()
@@ -117,7 +128,9 @@ class EmailDevice(CooldownMixin, ThrottlingMixin, SideChannelDevice):
             verified = super().verify_token(token)
 
             if verified:
-                self.throttle_reset()
+                self.throttle_reset(commit=False)
+                self.set_last_used_timestamp(commit=False)
+                self.save()
             else:
                 self.throttle_increment()
         else:
