@@ -7,7 +7,12 @@ from django.db import IntegrityError
 from django.test.utils import override_settings
 
 from django_otp.forms import OTPAuthenticationForm
-from django_otp.tests import CooldownTestMixin, TestCase, ThrottlingTestMixin
+from django_otp.tests import (
+    CooldownTestMixin,
+    TestCase,
+    ThrottlingTestMixin,
+    TimestampTestMixin,
+)
 
 from .models import EmailDevice
 
@@ -34,7 +39,7 @@ class AuthFormTest(EmailDeviceMixin, TestCase):
         data = {
             'username': 'alice',
             'password': 'password',
-            'otp_device': 'otp_email.emaildevice/1',
+            'otp_device': self.device.persistent_id,
             'otp_token': '',
             'otp_challenge': '1',
         }
@@ -268,3 +273,14 @@ class CooldownTestCase(EmailDeviceMixin, CooldownTestMixin, TestCase):
             self.device.refresh_from_db()
             message = self.device.generate_challenge()
             self.assertIn("Next generation allowed 5\xa0seconds from now.", message)
+
+
+class TimestampTestCase(EmailDeviceMixin, TimestampTestMixin, TestCase):
+    def valid_token(self):
+        if self.device.token is None:
+            self.device.generate_token()
+
+        return self.device.token
+
+    def invalid_token(self):
+        return -1
