@@ -13,7 +13,7 @@ def add_static_token(username, token=None):
     """
     user = get_user_model().objects.get_by_natural_key(username)
 
-    device = next(StaticDevice.objects.filter(user=user).iterator(), None)
+    device = StaticDevice.objects.filter(user=user).first()
     if device is None:
         device = StaticDevice.objects.create(user=user, name='Backup Code')
 
