@@ -10,7 +10,7 @@ from django.test import RequestFactory
 from django.test.utils import override_settings
 from django.urls import reverse
 
-from django_otp.tests import TestCase, ThrottlingTestMixin
+from django_otp.tests import TestCase, ThrottlingTestMixin, TimestampTestMixin
 
 from .admin import TOTPDeviceAdmin
 from .models import TOTPDevice
@@ -268,14 +268,14 @@ class TOTPAdminTest(TestCase):
     def test_list_display_when_sensitive_information_hidden(self):
         self.assertEqual(
             self.device_admin.get_list_display(self.get_request),
-            ['user', 'name', 'confirmed'],
+            ['user', 'name', 'created_at', 'last_used_at', 'confirmed'],
         )
 
     @override_settings(OTP_ADMIN_HIDE_SENSITIVE_DATA=False)
     def test_list_display_when_sensitive_information_shown(self):
         self.assertEqual(
             self.device_admin.get_list_display(self.get_request),
-            ['user', 'name', 'confirmed', 'qrcode_link'],
+            ['user', 'name', 'created_at', 'last_used_at', 'confirmed', 'qrcode_link'],
         )
 
     @override_settings(OTP_ADMIN_HIDE_SENSITIVE_DATA=True)
@@ -335,3 +335,11 @@ class ThrottlingTestCase(TOTPDeviceMixin, ThrottlingTestMixin, TestCase):
 
     def invalid_token(self):
         return -1
+
+
+class TimetstampTestCase(TOTPDeviceMixin, TimestampTestMixin, TestCase):
+    def valid_token(self):
+        return self.tokens[3]
+
+    def invalid_token(self):
+        return -1
